@@ -21,9 +21,9 @@
 #include <tqtextstream.h>
 
 // KDE includes
-#include <kparts/part.h>
-#include <kparts/plugin.h>
-#include <kparts/factory.h>
+#include <tdeparts/part.h>
+#include <tdeparts/plugin.h>
+#include <tdeparts/factory.h>
 #include <kxmlgui.h>
 
 namespace KMF {
